@@ -20,4 +20,8 @@ SUPERVISOR_CONFD = getattr(conf, "SUPERVISOR_CONFD", "/etc/supervisor/conf.d/")
 NGINX_SITES = getattr(conf, "NGINX_SITES", "/etc/nginx/sites-available/")
 NGINX_SITES_ENABLED = getattr(conf, "NGINX_SITES_ENABLED", "/etc/nginx/sites-enabled/")
 
-HOLDERS_HOME = "/etc/deploy/apps"
\ No newline at end of file
+HOLDERS_HOME = getattr(conf, "HOLDERS_HOME", "/etc/deploy/apps")
+REMOTE_PASSWORD = getattr(conf, "REMOTE_PASSWORD", None)
+REMOTE_USER = getattr(conf, "REMOTE_USER", "deploy-remote")
+REMOTE_PORT = getattr(conf, "REMOTE_PORT", 10000)
+REMOTE_ADDRESS = getattr(conf, "REMOTE_ADDRESS", "0.0.0.0")
\ No newline at end of file
